@@ -1,10 +1,12 @@
-"""
-This class is used to propagate changes to a parent item. This is
-used for when an AWeberEntry has a dict item as on of the attributes
-in _data.  When changes are made to an item in this data dict, __setattr__
-gets called on the parent with the new state of the dict.
-"""
 class DataDict(object):
+    """This class is used to propagate changes to a parent item.
+
+    This is used for when an AWeberEntry has a dict item as one of the
+    attributes in _data.  When changes are made to an item in this data
+    dict, __setattr__ gets called on the parent with the new state of
+    the dict.
+
+    """
 
     def __init__(self, data, name, parent):
         self.parent = parent
